Calculators & Scheduling
========================

.. automodule:: cruiseplan.calculators
   :members:


cruiseplan.calculators.distance module
--------------------------------------

.. automodule:: cruiseplan.calculators.distance
   :members:
   :undoc-members:
   :show-inheritance:

cruiseplan.calculators.duration module
--------------------------------------

.. automodule:: cruiseplan.calculators.duration
   :members:
   :undoc-members:
   :show-inheritance:

cruiseplan.calculators.routing module
-------------------------------------

.. automodule:: cruiseplan.calculators.routing
   :members:
   :undoc-members:
   :show-inheritance:

cruiseplan.calculators.scheduler module
---------------------------------------

.. automodule:: cruiseplan.calculators.scheduler
   :members:
   :undoc-members:
   :show-inheritance: